==> 0.1.8.tar.gz: lib/components/tab_bar_widget/np_tab_bar.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:npay_component/components/tab_bar_widget/tab_button.dart';


class NPTabBar extends StatefulWidget {
  ///
  final List<String> titles;

  final List<Widget> tabView;

  final Function(int tabIndex) onChangeIndex;
  final TabController tabController;
  final EdgeInsetsGeometry padding;

  final Color color;

  const NPTabBar(
      {Key key,
        @required this.titles,
        this.onChangeIndex,
        this.padding = EdgeInsets.zero,
        this.color = Colors.white,
        @required this.tabController,
        @required this.tabView})
      : super(key: key);

  @override
  _NPTabBarState createState() => _NPTabBarState();
}

class _NPTabBarState extends State<NPTabBar> with TickerProviderStateMixin {

  @override
  void initState() {
    widget.tabController.addListener(() {
      widget.onChangeIndex(widget.tabController.index);
      setState(() {
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: widget.color,
      child: Stack(
        alignment: Alignment.topCenter,
        children: [
          Padding(
            padding: widget.padding,
            child: Container(
              height: 32,
              decoration: BoxDecoration(
                borderRadius: BorderRadius.all(Radius.circular(8.0)),
                color: Color(0xFFF4F6FA),
              ),
              child: Row(
                children: List.generate(widget.titles.length, (index) {
                  return Expanded(
                    child: TabButton(
                      selectedPage: widget.tabController.index,
                      pageNumber: index,
                      title: widget.titles[index],
                      onPressed: () {},
                    ),
                  );
                }).toList(),
              ),
            ),
          ),
          Column(
            children: [
              TabBar(
                labelPadding: EdgeInsets.zero,
                tabs: _listTabBar(widget.titles.length, widget.titles),
                controller: widget.tabController,
                labelColor: Colors.transparent,
                indicatorWeight: 1,
                indicatorColor: Colors.transparent,
              ),
              Expanded(
                child: TabBarView(
                  children: widget.tabView,
                  controller: widget.tabController,
                ),
              )
            ],
          ),

        ],
      ),
    );
  }

  _listTabBar(int length, List<String> titles) {
    return List.generate(
      length,
          (index) => Tab(
        text: '',
      ),
    );
  }
}

==> 1.0.0.tar.gz: lib/components/tab_bar_widget/np_tab_bar.dart <==
import 'package:flutter/material.dart';
import 'package:npay_component/components/tab_bar_widget/tab_button.dart';

class NPTabBar extends StatefulWidget {
  ///
  final List<String> titles;

  final List<Widget> tabView;

  final Function(int tabIndex)? onChangeIndex;
  final TabController tabController;
  final EdgeInsetsGeometry padding;

  final Color color;

  const NPTabBar(
      {Key? key,
      required this.titles,
      this.onChangeIndex,
      this.padding = EdgeInsets.zero,
      this.color = Colors.white,
      required this.tabController,
      required this.tabView})
      : super(key: key);

  @override
  _NPTabBarState createState() => _NPTabBarState();
}

class _NPTabBarState extends State<NPTabBar> with TickerProviderStateMixin {
  @override
  void initState() {
    widget.tabController.addListener(() {
      if (widget.onChangeIndex != null) {
        widget.onChangeIndex!(widget.tabController.index);
        setState(() {});
      }
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: widget.color,
      child: Stack(
        alignment: Alignment.topCenter,
        children: [
          Padding(
            padding: widget.padding,
            child: Container(
              height: 32,
              decoration: BoxDecoration(
                borderRadius: BorderRadius.all(Radius.circular(8.0)),
                color: Color(0xFFF4F6FA),
              ),
              child: Row(
                children: List.generate(widget.titles.length, (index) {
                  return Expanded(
                    child: TabButton(
                      selectedPage: widget.tabController.index,
                      pageNumber: index,
                      title: widget.titles[index],
                      onPressed: () {},
                    ),
                  );
                }).toList(),
              ),
            ),
          ),
          Column(
            children: [
              TabBar(
                labelPadding: EdgeInsets.zero,
                tabs: _listTabBar(widget.titles.length, widget.titles),
                controller: widget.tabController,
                labelColor: Colors.transparent,
                indicatorWeight: 1,
                indicatorColor: Colors.transparent,
              ),
              Expanded(
                child: TabBarView(
                  children: widget.tabView,
                  controller: widget.tabController,
                ),
              )
            ],
          ),
        ],
      ),
    );
  }

  _listTabBar(int length, List<String> titles) {
    return List.generate(
      length,
      (index) => Tab(
        text: '',
      ),
    );
  }
}
